Skip to contents

COICOP is reference classification published by the United Nations Statistics Division (UNSD) used in National accounts, Household Budget surveys (HBS), Price Statistics (HICP) and Purchasing Power Parities (PPP). Eurostat introduced a harmonised and revision of COICOP, yielding a single harmonised COICOP classification at the five-digit level.

Usage

ecoicop16_names

Format

ecoicop16_names

A data frame with 479 rows and 4 columns containing the code and description of the ECOICOP classification at various levels of aggregation, from division (COICOP2, e.g., 01 Food and non-alcoholic beverages) down to subclasses (COICOP5, e.g., 01.1.1.1 Rice).

code

ECOICOP code

coicop_level

Hierarchical level of ECOICOP classification, description

coicop_level

Hierarchical level of ECOICOP classification, code

description

ECOICOP description

Examples

ecoicop16_names |> dim()
#> [1] 479   3
ecoicop16_names |> names()
#> [1] "code"  "level" "name"